==> sancho-3.4.0.tgz: package/esm/stories/Sheet.stories.js <==
/** @jsx jsx */
import { jsx } from "@emotion/core";
import * as React from "react";
import { storiesOf } from "@storybook/react";
import { Sheet } from "../Sheet";
import { Button } from "../Button";
import { MenuList, MenuItem, MenuDivider } from "../Menu";
export var SheetExamples = storiesOf("Sheet", module)
    .add("basic example", function () {
    return (jsx(Example, { position: "left", label: "hi" },
        jsx("div", null,
            "Helloooo world!",
            jsx("button", null, "one"),
            jsx("button", null, "two"),
            jsx("button", null, "tjree"),
            jsx("button", null, "four"))));
})
    .add("Different positions", function () {
    var positions = ["top", "left", "right", "bottom"];
    var examples = positions.map(function (position) {
        return (jsx(React.Fragment, { key: position },
            jsx(Example, { position: position, label: position },
                jsx("div", null,
                    "Helloooo world!",
                    jsx("button", null, "one"),
                    jsx("button", null, "two"),
                    jsx("button", null, "tjree"),
                    jsx("button", null, "four")))));
    });
    return (jsx("div", { css: {
            display: "flex",
            justifyContent: "center",
            flexDirection: "column",
            alignItems: "center",
            height: "100%",
            "& > *": {
                margin: "1rem",
                width: "200px"
            }
        } }, examples));
})
    .add("Sheet menu", function () {
    return (jsx(Example, { position: "bottom" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: function () {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
})
    .add("Scroll lock", function () {
    return (jsx(Example, { position: "bottom" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: function () {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
})
    .add("vertical swipe test", function () {
    return (jsx(Example, { position: "top" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: function () {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
});
var Example = function (_a) {
    var _b = _a.label, label = _b === void 0 ? "show" : _b, _c = _a.position, position = _c === void 0 ? "left" : _c, children = _a.children;
    var _d = React.useState(false), show = _d[0], setShow = _d[1];
    return (jsx("div", { css: {
            minHeight: "150vh"
        } },
        jsx(Button, { onPress: function () { return setShow(true); } }, label),
        jsx(Sheet, { onRequestClose: function () { return setShow(false); }, isOpen: show, position: position }, children)));
};

==> sancho-3.4.1.tgz: package/esm/stories/Sheet.stories.js <==
/** @jsx jsx */
import { jsx } from "@emotion/core";
import * as React from "react";
import { storiesOf } from "@storybook/react";
import { Sheet } from "../Sheet";
import { Button } from "../Button";
import { MenuList, MenuItem, MenuDivider } from "../Menu";
export var SheetExamples = storiesOf("Sheet", module)
    .add("basic example", function () {
    return (jsx(Example, { position: "left", label: "hi" },
        jsx("div", null,
            "Helloooo world!",
            jsx("button", null, "one"),
            jsx("button", null, "two"),
            jsx("button", null, "tjree"),
            jsx("button", null, "four"),
            jsx("div", { "data-scroll-lock-scrollable": true, style: {
                    border: "1px solid",
                    width: "100px",
                    height: "100px",
                    overflow: "scroll"
                } },
                jsx("div", { style: { height: "200px" } }, "scrollable")))));
})
    .add("Different positions", function () {
    var positions = ["top", "left", "right", "bottom"];
    var examples = positions.map(function (position) {
        return (jsx(React.Fragment, { key: position },
            jsx(Example, { position: position, label: position },
                jsx("div", null,
                    "Helloooo world!",
                    jsx("button", null, "one"),
                    jsx("button", null, "two"),
                    jsx("button", null, "tjree"),
                    jsx("button", null, "four")))));
    });
    return (jsx("div", { css: {
            display: "flex",
            justifyContent: "center",
            flexDirection: "column",
            alignItems: "center",
            height: "100%",
            "& > *": {
                margin: "1rem",
                width: "200px"
            }
        } }, examples));
})
    .add("Sheet menu", function () {
    return (jsx(Example, { position: "bottom" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: function () {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
})
    .add("Scroll lock", function () {
    return (jsx(Example, { position: "bottom" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: function () {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
})
    .add("vertical swipe test", function () {
    return (jsx(Example, { position: "top" },
        jsx(MenuList, { css: { display: "block" } },
            jsx(MenuItem, null, "Hello world number 1"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, { disabled: true }, "Hello world number 2"),
            jsx(MenuItem, { onSelect: function () {
                    alert("selected!");
                } }, "try selecting me"),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuDivider, null),
            jsx(MenuItem, null, "Hello world number 2"),
            jsx(MenuItem, null, "Hello world number 2"))));
});
var Example = function (_a) {
    var _b = _a.label, label = _b === void 0 ? "show" : _b, _c = _a.position, position = _c === void 0 ? "left" : _c, children = _a.children;
    var _d = React.useState(false), show = _d[0], setShow = _d[1];
    return (jsx("div", { css: {
            minHeight: "150vh"
        } },
        jsx(Button, { onPress: function () { return setShow(true); } }, label),
        jsx(Sheet, { onRequestClose: function () { return setShow(false); }, isOpen: show, position: position }, children)));
};
